@@ -928,8 +928,8 @@ def test_smoothing():
         c2 = progressbar_rate(get_bar(our_file2.getvalue(), 3))
 
     # Check that medium smoothing's rate is between no and max smoothing rates
-    assert a < c < b
-    assert a2 < c2 < b2
+    assert a <= c <= b
+    assert a2 <= c2 <= b2
 
 
 @with_setup(pretest, posttest)
@@ -1654,3 +1654,11 @@ def test_unit_scale():
             pass
         out = our_file.getvalue()
         assert '900/900' in out
+
+
+@with_setup(pretest, posttest)
+def test_threading():
+    """Test multiprocess/thread-realted features"""
+    from multiprocessing import Lock
+    tqdm.set_lock(Lock())
+    # TODO: test interleaved output #445
